import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
export interface SecureBucketProps {
    readonly bucketName?: string;
    readonly encryption?: SecureBucketEncryption;
    readonly versioned?: boolean;
    readonly eventBridgeEnabled?: boolean;
    readonly lifecycleRules?: s3.LifecycleRule[];
    readonly objectOwnership?: SecureObjectOwnership;
}
export declare enum SecureBucketEncryption {
    /**
     * Server-side KMS encryption with a master key managed by KMS.
     */
    KMS_MANAGED = "KMS_MANAGED",
    /**
     * Server-side encryption with a master key managed by S3.
     */
    S3_MANAGED = "S3_MANAGED"
}
/**
 * The ObjectOwnership of the bucket.
 *
 * @see https://docs.aws.amazon.com/AmazonS3/latest/dev/about-object-ownership.html
 *
 */
export declare enum SecureObjectOwnership {
    /**
     * ACLs are disabled, and the bucket owner automatically owns
     * and has full control over every object in the bucket.
     * ACLs no longer affect permissions to data in the S3 bucket.
     * The bucket uses policies to define access control.
     */
    BUCKET_OWNER_ENFORCED = "BucketOwnerEnforced",
    /**
     * Objects uploaded to the bucket change ownership to the bucket owner .
     */
    BUCKET_OWNER_PREFERRED = "BucketOwnerPreferred",
    /**
     * The uploading account will own the object.
     */
    OBJECT_WRITER = "ObjectWriter"
}
export declare class SecureBucket extends s3.Bucket {
    constructor(scope: Construct, id: string, props?: SecureBucketProps);
}
